@@ -59,74 +59,72 @@ impl<A: Disp> Plotter<A> {
     }
 }
 
-///
-/// Main render function.
-///
-pub(crate) fn render<P: BaseAndPlotsFmt>(
-    mut writer: impl fmt::Write,
-    all: P,
-    boundx: ticks::DataBound<P::X>,
-    boundy: ticks::DataBound<P::Y>,
-    canvas: impl Borrow<Canvas>,
-) -> fmt::Result {
-    let (base_fmt, mut plot_fmt) = all.gen();
+struct Renderer<
+    PF: BaseFmtAndTicks,
+    P: RenderablePlotIterator<X = PF::X, Y = PF::Y>,
+    K: Borrow<Canvas>,
+> {
+    base: PF,
+    plots: P,
+    boundx: ticks::DataBound<PF::X>,
+    boundy: ticks::DataBound<PF::Y>,
+    canvas: K,
+}
 
-    //render background
-    {
-        let mut writer = tagger::new(&mut writer);
-        writer.single("circle", |d| {
-            d.attr("r", "1e5")?;
-            d.attr("class", "poloto_background")
-        })?;
+impl<PF: BaseFmtAndTicks, P: RenderablePlotIterator<X = PF::X, Y = PF::Y>, K: Borrow<Canvas>> Disp
+    for Renderer<PF, P, K>
+{
+    fn disp<T: std::fmt::Write>(self, mut writer: T) -> fmt::Result {
+        self.render(&mut writer)
     }
-
-    let canvas = canvas.borrow();
-
-    //
-    // Using `cargo bloat` determined that these lines reduces alot of code bloat.
-    //
-    let plot_fmt = plot_fmt.as_mut_dyn();
-
-    render::render_plot::render_plot(&mut writer, &boundx, &boundy, canvas, plot_fmt)?;
-
-    let (mut plot_fmt, xtick_info, ytick_info) = base_fmt.gen();
-
-    // reduce code bloat
-    let ticks: &mut dyn Iterator<Item = P::X> = &mut xtick_info.ticks.into_iter();
-    let xtick_info = TickInfoIt {
-        dash_size: xtick_info.dash_size,
-        ticks,
-    };
-
-    // reduce code bloat
-    let ticks: &mut dyn Iterator<Item = P::Y> = &mut ytick_info.ticks.into_iter();
-    let ytick_info = TickInfoIt {
-        dash_size: ytick_info.dash_size,
-        ticks,
-    };
-
-    render::render_base::render_base(
-        &mut writer,
-        &boundx,
-        &boundy,
-        &mut plot_fmt,
-        xtick_info,
-        ytick_info,
-        canvas,
-    )
 }
 
-pub struct TickInfoIt<I: Iterator> {
-    dash_size: Option<f64>,
-    ticks: I,
-}
+impl<PF: BaseFmtAndTicks, P: RenderablePlotIterator<X = PF::X, Y = PF::Y>, K: Borrow<Canvas>>
+    Renderer<PF, P, K>
+{
+    fn render<T: std::fmt::Write>(mut self, mut writer: T) -> fmt::Result {
+        //render background
+        {
+            let mut writer = tagger::new(&mut writer);
+            writer.single("circle", |d| {
+                d.attr("r", "1e5")?;
+                d.attr("class", "poloto_background")
+            })?;
+        }
 
-pub(crate) trait BaseAndPlotsFmt {
-    type X: PlotNum;
-    type Y: PlotNum;
-    type A: BaseFmtAndTicks<X = Self::X, Y = Self::Y>;
-    type B: RenderablePlotIterator<X = Self::X, Y = Self::Y>;
-    fn gen(self) -> (Self::A, Self::B);
+        let canvas = self.canvas.borrow();
+
+        //
+        // Using `cargo bloat` determined that these lines reduces alot of code bloat.
+        //
+        let plot_fmt = self.plots.as_mut_dyn();
+
+        render::render_plot::render_plot(
+            &mut writer,
+            &self.boundx,
+            &self.boundy,
+            canvas,
+            plot_fmt,
+        )?;
+
+        let (mut plot_fmt, mut xtick_info, mut ytick_info) = self.base.gen();
+
+        // reduce code bloat
+        let xtick_info = &mut xtick_info as &mut dyn ticks::TickInfoInt<Item = P::X>;
+
+        // reduce code bloat
+        let ytick_info = &mut ytick_info as &mut dyn ticks::TickInfoInt<Item = P::Y>;
+
+        render::render_base::render_base(
+            &mut writer,
+            &self.boundx,
+            &self.boundy,
+            &mut plot_fmt,
+            xtick_info,
+            ytick_info,
+            canvas,
+        )
+    }
 }
 
 ///
@@ -145,9 +143,9 @@ pub(crate) trait BaseFmtAndTicks {
     type X: PlotNum;
     type Y: PlotNum;
     type Fmt: BaseFmt<X = Self::X, Y = Self::Y>;
-    type XI: IntoIterator<Item = Self::X>;
-    type YI: IntoIterator<Item = Self::Y>;
-    fn gen(self) -> (Self::Fmt, TickInfo<Self::XI>, TickInfo<Self::YI>);
+    type XI: TickInfoInt<Item = Self::X>;
+    type YI: TickInfoInt<Item = Self::Y>;
+    fn gen(self) -> (Self::Fmt, Self::XI, Self::YI);
 }
 
 trait NumFmt {
@@ -496,11 +494,6 @@ impl<P: RenderablePlotIterator, K: Borrow<Canvas>> Stager<P, K> {
         (&self.boundx, &self.boundy)
     }
 
-    ///
-    /// Automatically create a tick distribution using the default
-    /// tick generators tied to a [`PlotNum`].
-    ///
-
     ///
     /// Automatically create a tick distribution using the default
     /// tick generators tied to a [`PlotNum`].
@@ -526,27 +519,22 @@ impl<P: RenderablePlotIterator, K: Borrow<Canvas>> Stager<P, K> {
     /// Move to final stage in pipeline collecting the title/xname/yname.
     /// Unlike [`Stager::plot`] User must supply own tick distribution.
     ///
-    pub fn plot_with<XI, YI, PF>(
-        self,
-        xtick: TickInfo<XI>,
-        ytick: TickInfo<YI>,
-        plot_fmt: PF,
-    ) -> Plotter<impl Disp>
+    pub fn plot_with<XI, YI, PF>(self, xtick: XI, ytick: YI, plot_fmt: PF) -> Plotter<impl Disp>
     where
-        XI: IntoIterator<Item = P::X>,
-        YI: IntoIterator<Item = P::Y>,
+        XI: TickInfoInt<Item = P::X>,
+        YI: TickInfoInt<Item = P::Y>,
         PF: BaseFmt<X = P::X, Y = P::Y>,
     {
         ///
         /// Wrap tick iterators and a [`PlotFmt`] behind the [`PlotFmtAll`] trait.
         ///
-        struct PlotAllStruct<XI: IntoIterator, YI: IntoIterator, PF: BaseFmt> {
-            xtick: TickInfo<XI>,
-            ytick: TickInfo<YI>,
+        struct PlotAllStruct<XI: TickInfoInt, YI: TickInfoInt, PF: BaseFmt> {
+            xtick: XI,
+            ytick: YI,
             fmt: PF,
         }
 
-        impl<XI: IntoIterator, YI: IntoIterator, PF: BaseFmt<X = XI::Item, Y = YI::Item>>
+        impl<XI: TickInfoInt, YI: TickInfoInt, PF: BaseFmt<X = XI::Item, Y = YI::Item>>
             BaseFmtAndTicks for PlotAllStruct<XI, YI, PF>
         where
             XI::Item: PlotNum,
@@ -558,7 +546,7 @@ impl<P: RenderablePlotIterator, K: Borrow<Canvas>> Stager<P, K> {
             type XI = XI;
             type YI = YI;
 
-            fn gen(self) -> (Self::Fmt, TickInfo<Self::XI>, TickInfo<Self::YI>) {
+            fn gen(self) -> (Self::Fmt, Self::XI, Self::YI) {
                 (self.fmt, self.xtick, self.ytick)
             }
         }
@@ -574,41 +562,9 @@ impl<P: RenderablePlotIterator, K: Borrow<Canvas>> Stager<P, K> {
     /// Create a plotter directly from a [`BaseFmtAndTicks`]
     ///
     fn plot_with_all<PF: BaseFmtAndTicks<X = P::X, Y = P::Y>>(self, p: PF) -> Plotter<impl Disp> {
-        struct Combine<A: BaseFmtAndTicks, B: RenderablePlotIterator> {
-            pub a: A,
-            pub b: B,
-        }
-
-        impl<A: BaseFmtAndTicks, B: RenderablePlotIterator<X = A::X, Y = A::Y>> BaseAndPlotsFmt
-            for Combine<A, B>
-        {
-            type X = A::X;
-            type Y = A::Y;
-            type A = A;
-            type B = B;
-            fn gen(self) -> (Self::A, Self::B) {
-                (self.a, self.b)
-            }
-        }
-
-        struct InnerPlotter<PF: BaseAndPlotsFmt, K: Borrow<Canvas>> {
-            all: PF,
-            boundx: ticks::DataBound<PF::X>,
-            boundy: ticks::DataBound<PF::Y>,
-            canvas: K,
-        }
-
-        impl<PF: BaseAndPlotsFmt, K: Borrow<Canvas>> Disp for InnerPlotter<PF, K> {
-            fn disp<T: std::fmt::Write>(self, mut writer: T) -> fmt::Result {
-                render::render(&mut writer, self.all, self.boundx, self.boundy, self.canvas)
-            }
-        }
-
-        let pp = InnerPlotter {
-            all: Combine {
-                a: p,
-                b: self.plots,
-            },
+        let pp = Renderer {
+            base: p,
+            plots: self.plots,
             boundx: self.boundx.data,
             boundy: self.boundy.data,
             canvas: self.canvas,
